<?php

namespace EventPortal\Domain\Util\Sidebar;

use EventPortal\Concerns\HasWhen;

class Link
{
    use HasWhen;

    /** @var null|string */
    public $name;

    /** @var null|string */
    public $icon;

    /** @var null|string */
    public $route;

    /** @var null|array */
    public $routeParams;

    /** @var null|string */
    public $permission;

    /** @var null|array<Link> */
    public $children;

    public function __construct(?string $name = null)
    {
        $this->name = $name;
    }

    public static function make(?string $name = null): self
    {
        return new static($name);
    }

    public function name(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function icon(string $icon): self
    {
        $this->icon = $icon;

        return $this;
    }

    public function route(string $route, ?array $routeParams = null): self
    {
        $this->route = $route;
        $this->routeParams = $routeParams;

        return $this;
    }

    public function permission(string $permission): self
    {
        $this->permission = $permission;

        return $this;
    }

    public function addChildren(array $links): self
    {
        $this->children = array_map(function (Link $link) {
            return $link->render();
        }, $links);

        return $this;
    }

    public function render(): array
    {
        return [
            'name' => $this->name,
            'route' => $this->route,
            'routeParams' => $this->routeParams,
            'icon' => $this->icon,
            'children' => $this->children,
            'permission' => $this->permission,
        ];
    }
}
