<?php

namespace EventPortal\Http\Controllers\Admin\Email;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Util\Notification\Facades\Notification;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\RedirectResponse;

class SendEventEmailController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:email.store');
    }

    public function __invoke(Event $event, EventEmail $email): RedirectResponse
    {
        $key = $email->getNotificationKey();
        $delegates = $event->delegates();

        if (request()->has('only_remaining') === true) {
            $delegates = $delegates->whereDoesntHave('notifications', function (Builder $query) use ($key) {
                return $query->where('key', $key);
            });
        }

        $delegates = $delegates->get()->pluck('user');

        Notification::make($key)
            ->to($delegates)
            ->replyTo($email->reply_to_address)
            ->event($event)
            ->send();

        toast()->success(trans('email.sent'));

        return redirect()->back();
    }
}
