<?php

namespace EventPortal\Http\Controllers\Delegate\Event\Form;

use EventPortal\Domain\Delegate\Models\DelegateFormData;
use EventPortal\Domain\Event\Form\Models\Form as FormModel;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Form\Facades\Form;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;

class StoreFormController
{
    public function __invoke(Request $request, Event $event, FormModel $form, FormStep $step): RedirectResponse
    {
        $eventDelegate = EventDelegate::forEventAndDelegate($event, $request->user()->delegate)->first();

        Form::makeFromDatabase($form, $step)
            ->model(new DelegateFormData)
            ->context($step, $event, $form, $eventDelegate)
            ->addHandlers(config("forms.{$form->type}.handlers.store"))
            ->validate($request->input())
            ->handle($request->input());

        if ($step->isLast() === true) {
            toast()->success("{$form->name} form completed successfully!");
        }

        return redirect()->route('delegate.form.index', ['form' => $form->slug, 'event' => $event->slug]);
    }
}
