<?php

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Column\TextColumn;
use EventPortal\Domain\Component\Filter\DropdownFilter;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Enums\InertiaMethod;

Table::make('admin.index')
    ->setFilters(function () {
        return [
            DropdownFilter::make('Filter by role')
                ->forColumn('role')
                ->options(Role::allAsOptions()),
        ];
    })
    ->setColumns(function () {
        return [
            TextColumn::make('First name')->default()->searchable()->sortable(),
            TextColumn::make('Last name')->default()->searchable()->sortable(),
            TextColumn::make('Email')->default()->searchable()->sortable(),
            TextColumn::make('Role')->default()->calculated()->value(function (Admin $admin) {
                return optional($admin->role)->label;
            }),
        ];
    })
    ->setRowAction(static function (Admin $admin) {
        return ButtonDropdown::make('Manage user')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.user.show', ['admin' => $admin]),
                Button::make('Edit')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.user.edit', ['admin' => $admin]),
            ]);
    });
