<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class SelectTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_set_value()
    {
        $select = Select::make('Event type')
            ->options([
                Option::make('Seminar'),
                Option::make('Single'),
            ]);

        $select->value('seminar');

        $this->assertEquals('seminar', $select->value);
    }

    /** @test **/
    public function can_set_options()
    {
        $select = Select::make('Manager')
            ->options([
                Option::make('Toby')->value(1),
                Option::make('Andy')->value(2),
            ]);

        $expected = [
            ['label' => 'Toby', 'value' => 1],
            ['label' => 'Andy', 'value' => 2],
        ];

        $this->assertEquals($expected, $select->options);
    }

    /** @test **/
    public function can_get_options_for_array()
    {
        $select = Select::make('Manager')
            ->options([
                Option::make('Toby')->value(1),
                Option::make('Andy')->value(2),
            ]);

        $expected = [
            'label' => 'Andy',
            'value' => 2,
        ];

        $this->assertSame($expected, $select->getOptions(2));
    }

    /** @test **/
    public function can_get_options_for_collection()
    {
        $select = Select::make('Manager')
            ->options([
                Option::make('Toby')->value(1),
                Option::make('Andy')->value(2),
            ]);

        factory(Admin::class)->create([
            'user_id' => factory(User::class)->create(['first_name' => 'Toby']),
        ]);

        factory(Admin::class)->create([
            'user_id' => factory(User::class)->create(['first_name' => 'Andy']),
        ]);

        $expected = [
            [
                'label' => 'Toby',
                'value' => 1,
            ],
            [
                'label' => 'Andy',
                'value' => 2,
            ],
        ];

        $this->assertSame($expected, $select->getOptions(Admin::all())->toArray());
    }
}
