<?php

namespace EventPortal\Tests\Unit\Feature;

use EventPortal\Http\Middleware\Feature;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Http\Request;
use LaravelFeature\Facade\Feature as FeatureFacade;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class FeatureMiddlewareTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function exception_is_thrown_if_feature_is_disabled()
    {
        $this->expectException(NotFoundHttpException::class);

        FeatureFacade::add('test_feature', false);

        (new Feature())->handle(
            Request::create('feature-test'),
            function () {},
            'test_feature'
        );
    }

    /** @test **/
    public function exception_is_not_thrown_if_feature_is_enabled()
    {
        FeatureFacade::add('test_feature', true);

        $response = (new Feature())->handle(
            Request::create('feature-test'),
            function () {},
            'test_feature'
        );

        $this->assertNull($response);
    }
}
