<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class SiteAreaTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    /** @test */
    public function admin()
    {
        $user = factory(User::class)->state('snapshot')->create();
        $user->admin()->create();

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAs($user)
                ->get(route('admin.event.index'))
                ->props()
        );
    }

    /** @test */
    public function delegate()
    {
        $user = factory(User::class)->state('snapshot')->create();
        $user->delegate()->create();

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAs($user)
                ->get(route('home'))
                ->props()
        );
    }

    /** @test */
    public function admin_viewing_delegate_gets_delegate_site_area()
    {
        $user = factory(User::class)->state('snapshot')->create();
        $user->admin()->create();
        $user->delegate()->create();

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAs($user)
                ->get(route('home'))
                ->props()
        );
    }
}
